package com.qianhe.system.utils;

import com.idrsolutions.image.png.PngCompressor;
import com.sun.image.codec.jpeg.JPEGCodec;
import com.sun.image.codec.jpeg.JPEGImageEncoder;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.imageio.*;
import javax.imageio.metadata.IIOMetadata;
import javax.imageio.stream.FileImageInputStream;
import javax.imageio.stream.FileImageOutputStream;
import javax.imageio.stream.ImageInputStream;
import javax.imageio.stream.ImageOutputStream;
import java.awt.image.BufferedImage;
import java.io.*;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Random;
import java.util.zip.GZIPOutputStream;

import static com.qianhe.common.utils.file.MimeTypeUtils.IMAGE_PNG;

/**
 * 图片压缩工具
 */
@Component
public class ImageThumbnailsUtil {

    @Value("${ruoyi.profile}")
    private String profile;

    /***
     * 压缩jpg、jpeg格式图片
     * @param inputImagePath
     * @param outputImagePath
     * @throws IOException
     */
    public void compressImage(String inputImagePath, String outputImagePath) throws IOException{
        // 指定原始图片路径
        inputImagePath = profile + inputImagePath.replace("/profile","");
        // 设置目标图片保存路径及名称
        outputImagePath = profile + outputImagePath.replace("/profile","");

        // 创建输入流对象
        FileInputStream fis = new FileInputStream(new File(inputImagePath));

        // 获取图片信息
        BufferedImage image = ImageIO.read(fis);

        // 创建输出流对象
        FileOutputStream fos = new FileOutputStream(new File(outputImagePath));

        // 将图片写入到输出流中并进行压缩处理
        JPEGImageEncoder encoder = JPEGCodec.createJPEGEncoder(fos);
        encoder.encode(image);

        // 关闭输入、输出流
        fis.close();
        fos.close();
    }

    /***
     * 压缩PNG格式图片
     * @param inputImagePath
     * @param outputImagePath
     * @throws IOException
     */
    public void compressImagePNG(String inputImagePath, String outputImagePath) throws IOException{
        // 指定原始图片路径
        inputImagePath = profile + inputImagePath.replace("/profile","");
        outputImagePath = profile + outputImagePath.replace("/profile","");
        File file = new File(inputImagePath); // 源文件
        File outfile = new File(outputImagePath); // 目标输出文件，可与源文件一致，一致会覆盖
        PngCompressor.compress(file, outfile);
    }
}
